<?php
/**
 * WooCommerce breadcrumb map.
 *
 * @package Cheshalo
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit; // Direct access not allowed.
}

if ( ! function_exists( 'cheshalo_get_vc_map_woocommerce_breadcrumb' ) ) {
	/**
	 * WooCommerce breadcrumb map.
	 */
	function cheshalo_get_vc_map_woocommerce_breadcrumb() {
		$typography = cheshalo_get_typography_map(
			array(
				'key'      => 'title',
				'selector' => '{{WRAPPER}} .woocommerce-breadcrumb',
				'group'    => esc_html__( 'Style', 'cheshalo' ),
			)
		);

		return array(
			'base'        => 'cheshalo_woocommerce_breadcrumb',
			'name'        => esc_html__( 'WooCommerce breadcrumbs', 'cheshalo' ),
			'category'    => cheshalo_get_tab_title_category_for_wpb( esc_html__( 'WooCommerce', 'cheshalo' ) ),
			'description' => esc_html__( 'WooCommerce current page breadcrumb', 'cheshalo' ),
			'icon'        => CHESHALO_ASSETS . '/images/vc-icon/sp-icons/sp-breadcrumb.svg',
			'params'      => array(
				array(
					'group'      => esc_html__( 'Style', 'cheshalo' ),
					'type'       => 'cheshalo_css_id',
					'param_name' => 'cheshalo_css_id',
				),

				array(
					'heading'          => esc_html__( 'Alignment', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'wd_select',
					'param_name'       => 'alignment',
					'style'            => 'images',
					'selectors'        => array(),
					'devices'          => array(
						'desktop' => array(
							'value' => 'left',
						),
					),
					'value'            => array(
						esc_html__( 'Left', 'cheshalo' )   => 'left',
						esc_html__( 'Center', 'cheshalo' ) => 'center',
						esc_html__( 'Right', 'cheshalo' )  => 'right',
					),
					'images'           => array(
						'left'   => CHESHALO_ASSETS_IMAGES . '/settings/align/left.jpg',
						'center' => CHESHALO_ASSETS_IMAGES . '/settings/align/center.jpg',
						'right'  => CHESHALO_ASSETS_IMAGES . '/settings/align/right.jpg',
					),
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				array(
					'heading'          => esc_html__( 'No wrap on mobile devices', 'cheshalo' ),
					'group'            => esc_html__( 'Style', 'cheshalo' ),
					'type'             => 'cheshalo_switch',
					'param_name'       => 'nowrap_md',
					'true_state'       => 'yes',
					'false_state'      => 'no',
					'default'          => 'no',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
				),

				$typography['font_family'],
				$typography['font_size'],
				$typography['font_weight'],
				$typography['text_transform'],
				$typography['font_style'],
				$typography['line_height'],

				array(
					'heading'    => esc_html__( 'CSS box', 'cheshalo' ),
					'group'      => esc_html__( 'Design Options', 'js_composer' ),
					'type'       => 'css_editor',
					'param_name' => 'css',
				),
				cheshalo_get_vc_responsive_spacing_map(),

				// Width option (with dependency Columns option, responsive).
				cheshalo_get_responsive_dependency_width_map( 'responsive_tabs' ),
				cheshalo_get_responsive_dependency_width_map( 'width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_desktop' ),
				cheshalo_get_responsive_dependency_width_map( 'width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_tablet' ),
				cheshalo_get_responsive_dependency_width_map( 'width_mobile' ),
				cheshalo_get_responsive_dependency_width_map( 'custom_width_mobile' ),
			),
		);
	}
}
